Stan Math Library: stan/math/prim/scal/err/check_positive_finite.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

check_positive_finite.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_ERR_CHECK_POSITIVE_FINITE_HPP
2 #define STAN_MATH_PRIM_SCAL_ERR_CHECK_POSITIVE_FINITE_HPP
3
4 #include <stan/math/prim/scal/err/check_positive.hpp>
5 #include <stan/math/prim/scal/err/check_finite.hpp>
6
7 namespace stan {
8 namespace math {
9
27 template <typename T_y>
28 inline bool check_positive_finite(const char* function,
29 const char* name,
30 const T_y& y) {
31 stan::math::check_positive(function, name, y);
32 stan::math::check_finite(function, name, y);
33
34 return true;
35 }
36
37 }
38 }
39 #endif
check_positive.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::check_positive
bool check_positive(const char *function, const char *name, const T_y &y)
Return true if y is positive.
Definition: check_positive.hpp:68
stan::math::check_finite
bool check_finite(const char *function, const char *name, const T_y &y)
Return true if y is finite.
Definition: check_finite.hpp:62
check_finite.hpp
stan::math::check_positive_finite
bool check_positive_finite(const char *function, const char *name, const T_y &y)
Return true if y is positive and finite.
Definition: check_positive_finite.hpp:28

[ Stan Home Page ] © 2011–2016, Stan Development Team.